sr_check_yml: Utility function housing all yml map checks, passes through...

Description Usage Arguments Value

Description

Utility function housing all yml map checks, passes through the map as a list object if all tests pass

Usage

1
sr_check_yml(yml_map)

Arguments

yml_map

path to a yml_map file

Value

an error if any tests fail, otherwise a list object of the file mappings


chriscardillo/stitchr documentation built on May 8, 2019, 11:54 a.m.