sr_match_sources: Takes raw nested data and nested input mapping to identify...

Description Usage Arguments Value

Description

Takes raw nested data and nested input mapping to identify header rows / which files could be matched

Usage

1
sr_match_sources(df_nested_imports, input_colnames_df)

Arguments

df_nested_imports

dataframe of file names and nested data

input_colnames_df

dataframe of input sources and nested desired colnames

Value

a crossing table with all input sources and which ones matched to each file. WARNING: FILES CAN MATCH TO MULTIPLE SOURCES AT THIS STAGE. DO NOT USE THIS FUNCTION AS AN END USER.


chriscardillo/stitchr documentation built on May 8, 2019, 11:54 a.m.