Description Usage Arguments Value
Utility function housing all yml map checks, passes through the map as a list object if all tests pass
1 | sr_check_yml(yml_map)
|
yml_map |
path to a yml_map file |
an error if any tests fail, otherwise a list object of the file mappings
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.