Description Usage Arguments Value
Takes raw nested data and nested input mapping to identify header rows / which files could be matched
1 | sr_match_sources(df_nested_imports, input_colnames_df)
|
df_nested_imports |
dataframe of file names and nested data |
input_colnames_df |
dataframe of input sources and nested desired colnames |
a crossing table with all input sources and which ones matched to each file. WARNING: FILES CAN MATCH TO MULTIPLE SOURCES AT THIS STAGE. DO NOT USE THIS FUNCTION AS AN END USER.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.